R/shiny_7_functional_assessment.R
ui_functional_assessment.Rd
Creates the UI interface for the Functional Assessment panel inside the Starlng Shiny application.
ui_functional_assessment(id)
The id of the shiny module, used to access the UI elements.
This function is a shiny module function and should be used in the context of the app created using the starlng_write_app function.
starlng_write_app