This function provides a recommendation of a pseudotime ordering based on the metadata available in the monocle object. The recommendation is done by selecting an end node from the diameter of the trajectory graph. The function identifies the metadata group whose centre is the closest to the starting point.